@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -26,6 +26,34 @@ class ApigatewayClient(AbstractClient):
     _service = 'apigateway'
 
 
+    def AttachPlugin(self, request):
+        """绑定插件到API上。
+
+        :param request: Request instance for AttachPlugin.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.AttachPluginRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.AttachPluginResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("AttachPlugin", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.AttachPluginResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def BindEnvironment(self, request):
         """本接口（BindEnvironment）用于绑定使用计划到服务或API。
         用户在发布服务到某个环境中后，如果 API 需要鉴权，还需要绑定使用计划才能进行调用，此接口用户将使用计划绑定到特定环境。
@@ -142,6 +170,62 @@ class ApigatewayClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def BuildAPIDoc(self, request):
+        """构建 API 文档
+
+        :param request: Request instance for BuildAPIDoc.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.BuildAPIDocRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.BuildAPIDocResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("BuildAPIDoc", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.BuildAPIDocResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateAPIDoc(self, request):
+        """创建 API 文档
+
+        :param request: Request instance for CreateAPIDoc.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.CreateAPIDocRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.CreateAPIDocResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateAPIDoc", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateAPIDocResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateApi(self, request):
         """本接口（CreateApi）用于创建 API 接口，创建 API 前，用户需要先创建服务，每个 API 都有自己归属的服务。
 
@@ -226,6 +310,34 @@ class ApigatewayClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreatePlugin(self, request):
+        """创建API网关插件。
+
+        :param request: Request instance for CreatePlugin.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.CreatePluginRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.CreatePluginResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreatePlugin", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreatePluginResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateService(self, request):
         """本接口（CreateService）用于创建服务。
         API 网关使用的最大单元为服务，每个服务中可创建多个 API 接口。每个服务有一个默认域名供客户调用，用户也可绑定自定义域名到此服务中。
@@ -284,6 +396,34 @@ class ApigatewayClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteAPIDoc(self, request):
+        """删除 API 文档
+
+        :param request: Request instance for DeleteAPIDoc.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.DeleteAPIDocRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.DeleteAPIDocResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteAPIDoc", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteAPIDocResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteApi(self, request):
         """本接口（DeleteApi）用于删除已经创建的API。
 
@@ -368,6 +508,34 @@ class ApigatewayClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeletePlugin(self, request):
+        """删除API网关插件
+
+        :param request: Request instance for DeletePlugin.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.DeletePluginRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.DeletePluginResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeletePlugin", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeletePluginResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteService(self, request):
         """本接口（DeleteService）用于删除 API 网关中某个服务。
 
@@ -483,6 +651,90 @@ class ApigatewayClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeAPIDocDetail(self, request):
+        """查询 API 文档详情
+
+        :param request: Request instance for DescribeAPIDocDetail.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribeAPIDocDetailRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.DescribeAPIDocDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeAPIDocDetail", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAPIDocDetailResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeAPIDocs(self, request):
+        """查询 API 文档列表
+
+        :param request: Request instance for DescribeAPIDocs.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribeAPIDocsRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.DescribeAPIDocsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeAPIDocs", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAPIDocsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeAllPluginApis(self, request):
+        """展示插件相关的API列表，包括已绑定的和未绑定的API信息。
+
+        :param request: Request instance for DescribeAllPluginApis.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribeAllPluginApisRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.DescribeAllPluginApisResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeAllPluginApis", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAllPluginApisResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeApi(self, request):
         """本接口（DescribeApi）用于查询用户 API 网关的 API 接口的详细信息。​
 
@@ -766,6 +1018,62 @@ class ApigatewayClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribePlugin(self, request):
+        """展示插件详情，支持按照插件ID进行。
+
+        :param request: Request instance for DescribePlugin.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribePluginRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.DescribePluginResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePlugin", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePluginResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribePluginApis(self, request):
+        """查询指定插件下绑定的API信息
+
+        :param request: Request instance for DescribePluginApis.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribePluginApisRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.DescribePluginApisResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePluginApis", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePluginApisResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribePlugins(self, request):
         """展示插件列表和详情，支持分页，支持按照插件类型查询，支持按照插件ID批量查询，支持按照插件名称查询。
 
@@ -1165,6 +1473,34 @@ class ApigatewayClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DetachPlugin(self, request):
+        """解除插件与API绑定
+
+        :param request: Request instance for DetachPlugin.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.DetachPluginRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.DetachPluginResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DetachPlugin", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DetachPluginResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DisableApiKey(self, request):
         """本接口（DisableApiKey）用于禁用一对 API 密钥。
 
@@ -1249,6 +1585,34 @@ class ApigatewayClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyAPIDoc(self, request):
+        """修改 API 文档
+
+        :param request: Request instance for ModifyAPIDoc.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.ModifyAPIDocRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.ModifyAPIDocResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyAPIDoc", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyAPIDocResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyApi(self, request):
         """本接口（ModifyApi）用于修改 API 接口，可调用此接口对已经配置的 API 接口进行编辑修改。修改后的 API 需要重新发布 API 所在的服务到对应环境方能生效。
 
@@ -1361,6 +1725,34 @@ class ApigatewayClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyPlugin(self, request):
+        """修改API网关插件。
+
+        :param request: Request instance for ModifyPlugin.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.ModifyPluginRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.ModifyPluginResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyPlugin", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyPluginResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyService(self, request):
         """本接口（ModifyService）用于修改服务的相关信息。当服务创建后，服务的名称、描述和服务类型均可被修改。
 
@@ -1502,6 +1894,34 @@ class ApigatewayClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ResetAPIDocPassword(self, request):
+        """重置API文档密码
+
+        :param request: Request instance for ResetAPIDocPassword.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.ResetAPIDocPasswordRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.ResetAPIDocPasswordResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ResetAPIDocPassword", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ResetAPIDocPasswordResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UnBindEnvironment(self, request):
         """本接口（UnBindEnvironment）用于将使用计划从特定环境解绑。
 
